# 贡献者公约行为准则

## 我们的承诺

我们作为成员、贡献者和领导者，承诺让每个人在参与社区时都能获得免受骚扰的体验，无论年龄、体型、显性或隐性残疾、民族、性别特征、性别认同与表达、经验水平、教育程度、社会经济地位、国籍、外貌、种族、宗教、性取向或性别认同为何。

我们承诺以促进开放、友善、多元、包容且健康的社区方式行事与互动。

## 我们的标准

为我们的社区营造积极环境的行为示例包括：

* 对他人展现同理心与善意  
* 尊重不同的观点、立场与经历  
* 给予并优雅接纳建设性反馈  
* 为自身错误承担责任，向受影响者致歉，并从中吸取教训

* 不仅关注什么对个人最有利，更要关注什么对整个社区最有利

不可接受的行为示例包括：

* 使用带有性暗示的语言或图像，以及任何形式的性关注或挑逗行为

* 恶意挑衅、侮辱或贬低性言论，以及人身攻击或政治攻击  
* 公开或私下的骚扰行为  
* 未经他人明确许可，公开其私人信息（如实际住址或电子邮箱地址）

* 其他在专业场合下可被合理视为不当的行为

## 执行职责

社区负责人有责任明确并执行我们的行为准则，对于任何他们认为不当、威胁、冒犯或有害的行为，将采取适当且公正的纠正措施。

社区负责人有权且有责任删除、编辑或拒绝不符合本行为准则的评论、提交、代码、Wiki 编辑、问题及其他贡献，并会在适当时说明管理决策的原因。

## 适用范围

本行为准则适用于所有社区空间，同时也适用于个人在公开场合正式代表社区时。代表我们社区的示例包括使用官方电子邮件地址、通过官方社交媒体账号发布内容，或在线上/线下活动中担任指定代表。

## 强制执行

任何虐待、骚扰或其他不可接受的行为实例均可向负责执行的社区领导者举报，举报邮箱为 aw@funstory.ai。  
所有投诉都将得到及时且公正的审核与调查。  

所有社区领导者均有义务尊重事件举报者的隐私与安全。

## 执行指南

社区领导者将依据以下《社区影响指南》判定行为后果，任何被视为违反本《行为准则》的行为都将按此处理：

### 1. 修正

**社区影响**：使用不当语言或在社区中被认为不专业或不受欢迎的其他行为。

**后果**：社区领导者将私下发出书面警告，明确说明违规行为的性质，并解释为何该行为不当。可能会要求公开道歉。

### 2. 警告

**社区影响**：通过单次事件或一系列行为造成的违规。

**后果**：警告并附带持续行为的后果。在指定时间内不得与相关人员互动，包括未经请求与执行行为准则的人员互动。这包括避免在社区空间以及社交媒体等外部渠道的互动。违反这些条款可能导致暂时或永久封禁。

### 3. 临时封禁

**社区影响**：严重违反社区标准，包括持续的不当行为。

**后果**：在指定时间内暂时禁止与社区进行任何形式的互动或公开交流。在此期间，不得与相关人员（包括执行行为准则的管理者）进行公开或私下互动。违反这些条款可能导致永久封禁。

### 4. 永久封禁

**社区影响**：表现出违反社区标准的行为模式，包括持续的不当行为、对个人的骚扰，或对某类人群的敌意或贬损言论。

**后果**：永久禁止在社区内进行任何形式的公开互动。

## 致谢

本行为准则改编自[贡献者公约][homepage] 2.0 版本，原文参见  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html。

社区影响指南的制定参考了[Mozilla 行为准则执行阶梯](https://github.com/mozilla/diversity)。

[homepage]: https://www.contributor-covenant.org

关于本行为准则的常见问题解答，请参阅 FAQ 页面  
https://www.contributor-covenant.org/faq。其他语言版本参见  
https://www.contributor-covenant.org/translations。

<div align="right"> 
<h6><small>本页面的部分内容由 GPT 翻译，可能包含错误。</small></h6>